Try again to fix Windows build of previous.
[libdcp.git] / src / cpl.h
index 7e6dac6f9f9fda666dcba9fce9409293af8cd0a5..8095108860847d29592d0d915d19a82e94078239 100644 (file)
--- a/src/cpl.h
+++ b/src/cpl.h
@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2014 Carl Hetherington <cth@carlh.net>
+    Copyright (C) 2014-2019 Carl Hetherington <cth@carlh.net>
 
     This file is part of libdcp.
 
@@ -51,7 +51,7 @@
 
 namespace dcp {
 
-class ReelAsset;
+class ReelMXF;
 class Reel;
 class XMLMetadata;
 class MXFMetadata;
@@ -116,9 +116,10 @@ public:
                return _reels;
        }
 
/** @return the ReelAssets in this CPL in all reels.
         */
-       std::list<boost::shared_ptr<const ReelAsset> > reel_assets () const;
+       std::list<boost::shared_ptr<const ReelMXF> > reel_mxfs () const;
+       std::list<boost::shared_ptr<ReelMXF> > reel_mxfs ();
 
        bool encrypted () const;
 
@@ -140,6 +141,20 @@ public:
                return _standard;
        }
 
+       std::list<Rating> ratings () const {
+               return _ratings;
+       }
+
+       void set_ratings (std::list<Rating> r) {
+               _ratings = r;
+       }
+
+       std::string content_version_label_text () const {
+               return _content_version_label_text;
+       }
+
+       static std::string static_pkl_type (Standard standard);
+
 protected:
        /** @return type string for PKLs for this asset */
        std::string pkl_type (Standard standard) const;
@@ -154,6 +169,7 @@ private:
        std::string _content_version_id;            ///< &lt;Id&gt; in &lt;ContentVersion&gt;
        std::string _content_version_label_text;    ///< &lt;LabelText&gt; in &lt;ContentVersion&gt;
        std::list<boost::shared_ptr<Reel> > _reels;
+       std::list<Rating> _ratings;
 
        /** Standard of CPL that was read in */
        boost::optional<Standard> _standard;
@@ -116,9 +116,10 @@ public:
        }
 
-       /** @return the ReelAssets in this CPL in all reels.
+       /** @return the ReelMXFs in this CPL in all reels.
         */